# (c)2015 Microsoft Corporation.  All rights reserved.  This document is provided "as-is." Information and views expressed in this document,
# including URL and other Internet Web site references, may change without notice. You bear the risk of using it. 
# This document does not provide you with any legal rights to any intellectual property in any Microsoft product.
# You may copy and use this document for your internal, reference purposes. You may modify this document for your internal purposes

# The following example shows how you would run this script to collect data from 1/1/2014 to 1/30/2014 from a SQL Instance
# named SQL01\Lync where you intend to store your data output in a folder named \\fileserver\CQM
#
# .\CQM.ps1 -StartTime "1/1/2014" -EndTime "1/30/2014" -QoECdrInstance "sql01\lync" -DataRoot "\\fileserver\CQM" -QoECdrVersion "Lync2010" 

[CmdletBinding()]
Param (
	[Parameter(Mandatory=$true)]
	[String]
	$StartTime
,
	[Parameter(Mandatory=$true)]
    [String]
    $EndTime
,
	[Parameter(Mandatory=$true)]
	[String]
	$QoECdrInstance
,
	[Parameter(Mandatory=$true)]
    [ValidateSet("Lync2010","Lync2013","SfB2015")] 
	[String]
 	$QoECdrVersion = $(throw "QoECdrVersion required. Specify Lync2010, Lync2013 or SfB2015") 
,
	[Parameter(Mandatory=$true)]
	[String]
	$DataRoot
,
	[Parameter(Mandatory=$false)]
    [ValidateSet("CQM","ClassifiedPoorCall","Custom")] 
	[String]
 	$PoorStreamCondition = "DefClassifiedPoorCall"
,
	[Parameter(Mandatory=$false)]
	[Boolean]
 	$ExcludeST = $false

)



function ExportDataFromSQLInputFile {
	param([string]$InputFileName, [string]$StartTime, [string]$EndTime, [string]$DataInstance, [string]$OutputFileName, [string]$Type, [string]$PSC, [boolean]$ExcludeST)

	$InputFile = [System.IO.File]::ReadAllText($InputFileName)
	$STString = ",(16396)"
	if ($ExcludeST) {
		$STString = ""
	}

	#Defined Connection String
	$connstring = "server=$DataInstance;trusted_connection=true;"

	#Define SQL Command     
	$command = New-Object System.Data.SqlClient.SqlCommand
	$command.CommandText = ((($InputFile.replace("###STARTTIME",$StartTime)).replace("###ENDTIME",$EndTime)).replace("###POORSTREAMCONDITION",$PSC)).replace("###EXCLUDEST",$STString)
	Write-Debug $connstring
	Write-Debug $command.CommandText
	$command.CommandTimeout = 3600
    
	#Make the connection to Server     
	$connection = New-Object System.Data.SqlClient.SqlConnection
	$connection.ConnectionString = $connstring
	$connection.Open()
	$command.Connection = $connection
     
	#Get the results
	$sqladapter = New-Object System.Data.SqlClient.SqlDataAdapter
	$sqladapter.SelectCommand = $command
	$results = New-Object System.Data.Dataset     
	$recordcount=$sqladapter.Fill($results)

	$verbosetext = "Query: "+$InputFileName.Substring($InputFileName.LastIndexOf("\")+1)+ " returned "+$recordcount+" rows"  
	Write-Verbose $verbosetext
     
	#Close the connection
	$connection.Close()

	# Only do something if we have records
	if ($recordcount -gt 0) {

		switch ($Type) {

			"Device" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn CaptureDeviceName,([string])
				$col2 = New-Object system.Data.DataColumn AvgSendListenMOS,([float])
				$col3 = New-Object system.Data.DataColumn NumStreams,([int])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.CaptureDeviceName = $_.CaptureDeviceName
					$row.AvgSendListenMOS = $_.AvgSendListenMOS
					$row.NumStreams = $_.NumStreams
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"System" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn CallerAudioMicGlitchRate,([int])
				$col3 = New-Object system.Data.DataColumn Caller,([string])
				$col4 = New-Object system.Data.DataColumn DeviceName,([string])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.CallerAudioMicGlitchRate = $_.CallerAudioMicGlitchRate
					$row.Caller = $_.Caller
					$row.DeviceName = $_.DeviceName
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			{($_ -eq "Relay") -or ($_ -eq "Transport")} {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ClientSubnet,([string])
				$col2 = New-Object system.Data.DataColumn Streams,([int])
				$col3 = New-Object system.Data.DataColumn AvgNetworkMOS,([float])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ClientSubnet = $_.ClientSubnet
					$row.Streams = $_.Streams
					$row.AvgNetworkMOS = $_.AvgNetworkMOS
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"VPN" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn TotalStreams,([int])
				$col2 = New-Object system.Data.DataColumn TotalVPNStreams,([int])
				$col3 = New-Object system.Data.DataColumn TotalPoorVPNStreams,([int])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.TotalStreams = $_.TotalStreams
					$row.TotalVPNStreams = $_.TotalVPNStreams
					$row.TotalPoorVPNStreams = $_.TotalPoorVPNStreams
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 


			"LastMile" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn ClientSubnet,([string])
				$col3 = New-Object system.Data.DataColumn AllStreams,([int])
				$col4 = New-Object system.Data.DataColumn PoorStreams,([int])
				$col5 = New-Object system.Data.DataColumn PoorStreamsRatio,([float])


				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.ClientSubnet = $_.ClientSubnet
					$row.AllStreams = $_.AllStreams
					$row.PoorStreams = $_.PoorStreams
					$row.PoorStreamsRatio = $_.PoorStreamsRatio
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"Plant1" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn AVMCU,([string])
				$col3 = New-Object system.Data.DataColumn MS,([string])
				$col4 = New-Object system.Data.DataColumn AllStreams,([int])
				$col5 = New-Object system.Data.DataColumn PoorStreams,([int])
				$col6 = New-Object system.Data.DataColumn PoorStreamsRatio,([float])


				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.AVMCU = $_.AVMCU
					$row.MS = $_.MS
					$row.AllStreams = $_.AllStreams
					$row.PoorStreams = $_.PoorStreams
					$row.PoorStreamsRatio = $_.PoorStreamsRatio
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"Plant2" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn MS,([string])
				$col3 = New-Object system.Data.DataColumn GW,([string])
				$col4 = New-Object system.Data.DataColumn AllStreams,([int])
				$col5 = New-Object system.Data.DataColumn PoorStreams,([int])
				$col6 = New-Object system.Data.DataColumn PoorStreamsRatio,([float])


				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.MS = $_.MS
					$row.GW = $_.GW
					$row.AllStreams = $_.AllStreams
					$row.PoorStreams = $_.PoorStreams
					$row.PoorStreamsRatio = $_.PoorStreamsRatio
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 


			"Trend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn AllStreams,([int])
				$col3 = New-Object system.Data.DataColumn PoorStreams,([int])
				$col4 = New-Object system.Data.DataColumn PoorStreamsRatio,([float])
				$col5 = New-Object system.Data.DataColumn QueryType,([string])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.AllStreams = $_.AllStreams
					$row.PoorStreams = $_.PoorStreams
					$row.PoorStreamsRatio = $_.PoorStreamsRatio
					$row.QueryType = $_.QueryType
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 
			"RMC" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ReportDate,([string])
				$col2 = New-Object system.Data.DataColumn AllRatings,([int])
				$col3 = New-Object system.Data.DataColumn AvgRating,([float])
				$col4 = New-Object system.Data.DataColumn QueryType,([string])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.ReportDate = $_.ReportDate.ToShortDateString()
					$row.AllRatings = $_.AllRatings
					$row.AvgRating = $_.AvgRating
					$row.QueryType = $_.QueryType
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"Util1" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn CaptureDeviceName,([string])
				$col2 = New-Object system.Data.DataColumn Caller,([string])
				$col3 = New-Object system.Data.DataColumn AvgSendListenMOS,([float])
				$col4 = New-Object system.Data.DataColumn AvgAudioMicGlitchRate,([float])
				$col5 = New-Object system.Data.DataColumn NumStreams,([int])

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.CaptureDeviceName = $_.CaptureDeviceName
					$row.Caller = $_.Caller
					$row.AvgSendListenMOS = $_.AvgSendListenMOS
					$row.AvgAudioMicGlitchRate = $_.AvgAudioMicGlitchRate
					$row.NumStreams = $_.NumStreams
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 
			"ConfTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ConferenceDate,([string])
                		$col1.ColumnName = "Conference Date"
				$col2 = New-Object system.Data.DataColumn NumberOfConferenceSessions,([int])
		                $col2.ColumnName = "Number Of Conference Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfFailToEstablishConferenceSessions,([int])
                		$col3.ColumnName = "Number Of Fail-To-Establish Conference Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfFailToEstablishConferenceSessions_pct,([float])
        		        $col4.ColumnName = "Number Of Fail-To-Establish Conference Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfMidCallFailConferenceSessions,([int])
                		$col5.ColumnName = "Number Of Mid-Call-Fail Conference Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfMidCallFailConferenceSessions_pct,([float])
		                $col6.ColumnName = "Number Of Mid-Call-Fail Conference Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Conference Date' = $_.ConferenceDate.ToShortDateString()
					$row.'Number Of Conference Sessions' = $_.NumberOfConferenceSessions
					$row.'Number Of Fail-To-Establish Conference Sessions' = $_.NumberOfFailToEstablishConferenceSessions
					$row.'Number Of Fail-To-Establish Conference Sessions (%)' = [math]::round($_.NumberOfFailToEstablishConferenceSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail Conference Sessions' = $_.NumberOfMidCallFailConferenceSessions
					$row.'Number Of Mid-Call-Fail Conference Sessions (%)' = [math]::round($_.NumberOfMidCallFailConferenceSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"ConfFailToEstablishTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ConferenceDate,([string])
		                $col1.ColumnName = "Conference Date"
				$col2 = New-Object system.Data.DataColumn NumberOfConferenceSessions,([int])
                		$col2.ColumnName = "Number Of Conference Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfFailToEstablishAVMCUConferenceSessions,([int])
		                $col3.ColumnName = "Number Of Fail-To-Establish AVMCU Conference Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfFailToEstablishAVMCUConferenceSessions_pct,([float])
		                $col4.ColumnName = "Number Of Fail-To-Establish AVMCU Conference Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfFailToEstablishASMCUConferenceSessions,([int])
                		$col5.ColumnName = "Number Of Fail-To-Establish ASMCU Conference Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfFailToEstablishASMCUConferenceSessions_pct,([float])
		                $col6.ColumnName = "Number Of Fail-To-Establish ASMCU ConferenceSessions (%)"
				$col7 = New-Object system.Data.DataColumn NumberOfFailToEstablishIMMCUConferenceSessions,([int])
                		$col7.ColumnName = "Number Of Fail-To-Establish IMMCU Conference Sessions"
				$col8 = New-Object system.Data.DataColumn NumberOfFailToEstablishIMMCUConferenceSessions_pct,([float])
		                $col8.ColumnName = "Number Of Fail-To-Establish IMMCU Conference Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Conference Date' = $_.ConferenceDate.ToShortDateString()
					$row.'Number Of Conference Sessions' = $_.NumberOfConferenceSessions
					$row.'Number Of Fail-To-Establish AVMCU Conference Sessions' = $_.NumberOfFailToEstablishAVMCUConferenceSessions
					$row.'Number Of Fail-To-Establish AVMCU Conference Sessions (%)' = [math]::round($_.NumberOfFailToEstablishAVMCUConferenceSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish ASMCU Conference Sessions' = $_.NumberOfFailToEstablishASMCUConferenceSessions
					$row.'Number Of Fail-To-Establish ASMCU ConferenceSessions (%)' = [math]::round($_.NumberOfFailToEstablishASMCUConferenceSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish IMMCU Conference Sessions' = $_.NumberOfFailToEstablishIMMCUConferenceSessions
					$row.'Number Of Fail-To-Establish IMMCU Conference Sessions (%)' = [math]::round($_.NumberOfFailToEstablishIMMCUConferenceSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"ConfFailMidCallEstablishTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ConferenceDate,([string])
		                $col1.ColumnName = "Conference Date"
				$col2 = New-Object system.Data.DataColumn NumberOfConferenceSessions,([int])
                		$col2.ColumnName = "Number Of Conference Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfMidCallFailAVMCUConferenceSessions,([int])
		                $col3.ColumnName = "Number Of Mid-Call-Fail AVMCU Conference Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfMidCallFailAVMCUConferenceSessions_pct,([float])
                		$col4.ColumnName = "Number Of Mid-Call-Fail AVMCU Conference Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfMidCallFailASMCUConferenceSessions,([int])
		                $col5.ColumnName = "Number Of Mid-Call-Fail ASMCU Conference Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfMidCallFailASMCUConferenceSessions_pct,([float])
		                $col6.ColumnName = "Number Of Mid-Call-Fail ASMCU Conference Sessions (%)"
				$col7 = New-Object system.Data.DataColumn NumberOfMidCallFailIMMCUConferenceSessions,([int])
                		$col7.ColumnName = "Number Of Mid-Call-Fail IMMCU Conference Sessions"
				$col8 = New-Object system.Data.DataColumn NumberOfMidCallFailIMMCUConferenceSessions_pct,([float])
		                $col8.ColumnName = "Number Of Mid-Call-Fail IMMCU Conference Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Conference Date' = $_.ConferenceDate.ToShortDateString()
					$row.'Number Of Conference Sessions' = $_.NumberOfConferenceSessions
					$row.'Number Of Mid-Call-Fail AVMCU Conference Sessions' = $_.NumberOfMidCallFailAVMCUConferenceSessions
					$row.'Number Of Mid-Call-Fail AVMCU Conference Sessions (%)' = [math]::round($_.NumberOfMidCallFailAVMCUConferenceSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail ASMCU Conference Sessions' = $_.NumberOfMidCallFailASMCUConferenceSessions
					$row.'Number Of Mid-Call-Fail ASMCU Conference Sessions (%)' = [math]::round($_.NumberOfMidCallFailASMCUConferenceSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail IMMCU Conference Sessions' = $_.NumberOfMidCallFailIMMCUConferenceSessions
					$row.'Number Of Mid-Call-Fail IMMCU Conference Sessions (%)' = [math]::round($_.NumberOfMidCallFailIMMCUConferenceSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 
			
			"ConfPSTNFailureTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn ConferenceDate,([string])
		                $col1.ColumnName = "Conference Date"
				$col2 = New-Object system.Data.DataColumn NumberOfConferencePSTNLegs,([int])
                		$col2.ColumnName = "Number Of Conference PSTN Legs"
				$col3 = New-Object system.Data.DataColumn NumberOf4xx,([int])
		                $col3.ColumnName = "Number Of Client Failure Responses (4xx)"
				$col4 = New-Object system.Data.DataColumn NumberOf4xx_pct,([float])
                		$col4.ColumnName = "Number Of Client Failure Responses (4xx) (%)"
				$col5 = New-Object system.Data.DataColumn NumberOf5xx,([int])
		                $col5.ColumnName = "Number Of Server Failure Responses (5xx)"
				$col6 = New-Object system.Data.DataColumn NumberOf5xx_pct,([float])
                		$col6.ColumnName = "Number Of Server Failure Responses (5xx) (%)"
				$col7 = New-Object system.Data.DataColumn NumberOf6xx,([int])
		                $col7.ColumnName = "Number Of Global Failure Responses (6xx)"
				$col8 = New-Object system.Data.DataColumn NumberOf6xx_pct,([float])
                		$col8.ColumnName = "Number Of Global Failure Responses (6xx) (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Conference Date' = $_.ConferenceDate.ToShortDateString()
					$row.'Number Of Conference PSTN Legs' = $_.NumberOfConferencePSTNLegs
					$row.'Number Of Client Failure Responses (4xx)' = $_.NumberOf4xx
					$row.'Number Of Client Failure Responses (4xx) (%)' = [math]::round($_.NumberOf4xx_pct*100,2)
					$row.'Number Of Server Failure Responses (5xx)' = $_.NumberOf5xx
					$row.'Number Of Server Failure Responses (5xx) (%)' = [math]::round($_.NumberOf5xx_pct*100,2)
					$row.'Number Of Global Failure Responses (6xx)' = $_.NumberOf6xx
					$row.'Number Of Global Failure Responses (6xx) (%)' = [math]::round($_.NumberOf6xx_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 
			
			"P2PTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn SessionDate,([string])
		                $col1.ColumnName = "Session Date"
				$col2 = New-Object system.Data.DataColumn NumberOfP2PSessions,([int])
                		$col2.ColumnName = "Number Of P2P Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfFailToEstablishP2PSessions,([int])
		                $col3.ColumnName = "Number Of Fail-To-Establish P2P Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfFailToEstablishP2PSessions_pct,([float])
                		$col4.ColumnName = "Number Of Fail-To-Establish P2P Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfMidCallFailP2PSessions,([int])
		                $col5.ColumnName = "Number Of Mid-Call-Fail P2P Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfMidCallFailP2PSessions_pct,([float])
                		$col6.ColumnName = "Number Of Mid-Call-Fail P2P Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Session Date' = $_.SessionDate.ToShortDateString()
					$row.'Number Of P2P Sessions' = $_.NumberOfP2PSessions
					$row.'Number Of Fail-To-Establish P2P Sessions' = $_.NumberOfFailToEstablishP2PSessions
					$row.'Number Of Fail-To-Establish P2P Sessions (%)' = [math]::round($_.NumberOfFailToEstablishP2PSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail P2P Sessions' = $_.NumberOfMidCallFailP2PSessions
					$row.'Number Of Mid-Call-Fail P2P Sessions (%)' = [math]::round($_.NumberOfMidCallFailP2PSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"P2PFailToEstablishTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn SessionDate,([string])
		                $col1.ColumnName = "Session Date"
				$col2 = New-Object system.Data.DataColumn NumberOfP2PSessions,([int])
                		$col2.ColumnName = "Number Of P2P Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfFailToEstablishIMSessions,([int])
		                $col3.ColumnName = "Number Of Fail-To-Establish IM Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfFailToEstablishIMSessions_pct,([float])
                		$col4.ColumnName = "Number Of Fail-To-Establish IM Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfFailToEstablishFTSessions,([int])
		                $col5.ColumnName = "Number Of Fail-To-Establish FT Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfFailToEstablishFTSessions_pct,([float])
                		$col6.ColumnName = "Number Of Fail-To-Establish FT Sessions (%)"
				$col7 = New-Object system.Data.DataColumn NumberOfFailToEstablishAppSharingSessions,([int])
		                $col7.ColumnName = "Number Of Fail-To-Establish App Sharing Sessions"
				$col8 = New-Object system.Data.DataColumn NumberOfFailToEstablishAppSharingSessions_pct,([float])
                		$col8.ColumnName = "Number Of Fail-To-Establish App Sharing Sessions (%)"
				$col9 = New-Object system.Data.DataColumn NumberOfFailToEstablishAudioSessions,([int])
		                $col9.ColumnName = "Number Of Fail-To-Establish Audio Sessions"
				$col10 = New-Object system.Data.DataColumn NumberOfFailToEstablishAudioSessions_pct,([float])
                		$col10.ColumnName = "Number Of Fail-To-Establish Audio Sessions (%)"
				$col11 = New-Object system.Data.DataColumn NumberOfFailToEstablishAudioVideoSessions,([int])
		                $col11.ColumnName = "Number Of Fail-To-Establish Audio Video Sessions"
				$col12 = New-Object system.Data.DataColumn NumberOfFailToEstablishAudioVideoSessions_pct,([float])
                		$col12.ColumnName = "Number Of Fail-To-Establish Audio Video Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)
				$datatable.columns.add($col9)
				$datatable.columns.add($col10)
				$datatable.columns.add($col11)
				$datatable.columns.add($col12)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Session Date' = $_.SessionDate.ToShortDateString()
					$row.'Number Of P2P Sessions' = $_.NumberOfP2PSessions
					$row.'Number Of Fail-To-Establish IM Sessions' = $_.NumberOfFailToEstablishIMSessions
					$row.'Number Of Fail-To-Establish IM Sessions (%)' = [math]::round($_.NumberOfFailToEstablishIMSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish FT Sessions' = $_.NumberOfFailToEstablishFTSessions
					$row.'Number Of Fail-To-Establish FT Sessions (%)' = [math]::round($_.NumberOfFailToEstablishFTSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish App Sharing Sessions' = $_.NumberOfFailToEstablishAppSharingSessions
					$row.'Number Of Fail-To-Establish App Sharing Sessions (%)' = [math]::round($_.NumberOfFailToEstablishAppSharingSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish Audio Sessions' = $_.NumberOfFailToEstablishAudioSessions
					$row.'Number Of Fail-To-Establish Audio Sessions (%)' = [math]::round($_.NumberOfFailToEstablishAudioSessions_pct*100,2)
					$row.'Number Of Fail-To-Establish Audio Video Sessions' = $_.NumberOfFailToEstablishAudioVideoSessions
					$row.'Number Of Fail-To-Establish Audio Video Sessions (%)' = [math]::round($_.NumberOfFailToEstablishAudioVideoSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"P2PFailMidCallEstablishTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn SessionDate,([string])
		                $col1.ColumnName = "Session Date"
				$col2 = New-Object system.Data.DataColumn NumberOfP2PSessions,([int])
                		$col2.ColumnName = "Number Of P2P Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfMidCallFailIMSessions,([int])
		                $col3.ColumnName = "Number Of Mid-Call-Fail IM Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfMidCallFailIMSessions_pct,([float])
                		$col4.ColumnName = "Number Of Mid-Call-Fail IM Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfMidCallFailFTSessions,([int])
		                $col5.ColumnName = "Number Of Mid-Call-Fail FT Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfMidCallFailFTSessions_pct,([float])
                		$col6.ColumnName = "Number Of Mid-Call-Fail FT Sessions (%)"
				$col7 = New-Object system.Data.DataColumn NumberOfMidCallFailAppSharingSessions,([int])
		                $col7.ColumnName = "Number Of Mid-Call-Fail App Sharing Sessions"
				$col8 = New-Object system.Data.DataColumn NumberOfMidCallFailAppSharingSessions_pct,([float])
                		$col8.ColumnName = "Number Of Mid-Call-Fail App Sharing Sessions (%)"
				$col9 = New-Object system.Data.DataColumn NumberOfMidCallFailAudioSessions,([int])
		                $col9.ColumnName = "Number Of Mid-Call-Fail Audio Sessions"
				$col10 = New-Object system.Data.DataColumn NumberOfMidCallFailAudioSessions_pct,([float])
                		$col10.ColumnName = "Number Of Mid-Call-Fail Audio Sessions (%)"
				$col11 = New-Object system.Data.DataColumn NumberOfMidCallFailAudioVideoSessions,([int])
		                $col11.ColumnName = "Number Of Mid-Call-Fail Audio Video Sessions"
				$col12 = New-Object system.Data.DataColumn NumberOfMidCallFailAudioVideoSessions_pct,([float])
                		$col12.ColumnName = "Number Of Mid-Call-Fail Audio Video Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)
				$datatable.columns.add($col9)
				$datatable.columns.add($col10)
				$datatable.columns.add($col11)
				$datatable.columns.add($col12)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'Session Date' = $_.SessionDate.ToShortDateString()
					$row.'Number Of P2P Sessions' = $_.NumberOfP2PSessions
					$row.'Number Of Mid-Call-Fail IM Sessions' = $_.NumberOfMidCallFailIMSessions
					$row.'Number Of Mid-Call-Fail IM Sessions (%)' = [math]::round($_.NumberOfMidCallFailIMSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail FT Sessions' = $_.NumberOfMidCallFailFTSessions
					$row.'Number Of Mid-Call-Fail FT Sessions (%)' = [math]::round($_.NumberOfMidCallFailFTSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail App Sharing Sessions' = $_.NumberOfMidCallFailAppSharingSessions
					$row.'Number Of Mid-Call-Fail App Sharing Sessions (%)' = [math]::round($_.NumberOfMidCallFailAppSharingSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail Audio Sessions' = $_.NumberOfMidCallFailAudioSessions
					$row.'Number Of Mid-Call-Fail Audio Sessions (%)' = [math]::round($_.NumberOfMidCallFailAudioSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail Audio Video Sessions' = $_.NumberOfMidCallFailAudioVideoSessions
					$row.'Number Of Mid-Call-Fail Audio Video Sessions (%)' = [math]::round($_.NumberOfMidCallFailAudioVideoSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"PSTNTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn VoIPSessionDate,([string])
		                $col1.ColumnName = "PSTN Session Date"
				$col2 = New-Object system.Data.DataColumn NumberOfVoIPSessions,([int])
                		$col2.ColumnName = "Number Of PSTN Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOfFailToEstablishVoIPSessions,([int])
		                $col3.ColumnName = "Number Of Fail-To-Establish PSTN Sessions"
				$col4 = New-Object system.Data.DataColumn NumberOfFailToEstablishVoIPSessions_pct,([float])
                		$col4.ColumnName = "Number Of Fail-To-Establish PSTN Sessions (%)"
				$col5 = New-Object system.Data.DataColumn NumberOfMidCallFailVoIPSessions,([int])
		                $col5.ColumnName = "Number Of Mid-Call-Fail PSTN Sessions"
				$col6 = New-Object system.Data.DataColumn NumberOfMidCallFailVoIPSessions_pct,([float])
                		$col6.ColumnName = "Number Of Mid-Call-Fail PSTN Sessions (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'PSTN Session Date' = $_.VoIPSessionDate.ToShortDateString()
					$row.'Number Of PSTN Sessions' = $_.NumberOfVoIPSessions
					$row.'Number Of Fail-To-Establish PSTN Sessions' = $_.NumberOfFailToEstablishVoIPSessions
					$row.'Number Of Fail-To-Establish PSTN Sessions (%)' = [math]::round($_.NumberOfFailToEstablishVoIPSessions_pct*100,2)
					$row.'Number Of Mid-Call-Fail PSTN Sessions' = $_.NumberOfMidCallFailVoIPSessions
					$row.'Number Of Mid-Call-Fail PSTN Sessions (%)' = [math]::round($_.NumberOfMidCallFailVoIPSessions_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 

			"PSTNFailuresTrend" {
				# Create a temp table
				$datatable = new-object System.Data.DataTable "tmpTable"
				$col1 = New-Object system.Data.DataColumn VoIPSessionDate,([string])
		                $col1.ColumnName = "PSTN Session Date"
				$col2 = New-Object system.Data.DataColumn NumberOfVoIPSessions,([int])
                		$col2.ColumnName = "Number Of PSTN Sessions"
				$col3 = New-Object system.Data.DataColumn NumberOf4xx,([int])
		                $col3.ColumnName = "Number Of Client Failure Responses (4xx)"
				$col4 = New-Object system.Data.DataColumn NumberOf4xx_pct,([float])
                		$col4.ColumnName = "Number Of Client Failure Responses (4xx) (%)"
				$col5 = New-Object system.Data.DataColumn NumberOf5xx,([int])
		                $col5.ColumnName = "Number Of Server Failure Responses (5xx)"
				$col6 = New-Object system.Data.DataColumn NumberOf5xx_pct,([float])
                		$col6.ColumnName = "Number Of Server Failure Responses (5xx) (%)"
				$col7 = New-Object system.Data.DataColumn NumberOf6xx,([int])
                		$col7.ColumnName = "Number Of Global Failure Responses (6xx)"
				$col8 = New-Object system.Data.DataColumn NumberOf6xx_pct,([float])
		                $col8.ColumnName = "Number Of Global Failure Responses (6xx) (%)"

				#Add the Columns
				$datatable.columns.add($col1)
				$datatable.columns.add($col2)
				$datatable.columns.add($col3)
				$datatable.columns.add($col4)
				$datatable.columns.add($col5)
				$datatable.columns.add($col6)
				$datatable.columns.add($col7)
				$datatable.columns.add($col8)

				# Run through all rows in results
				$results.tables[0] | foreach-object {

					#Create a row
					$row = $datatable.NewRow()
					$row.'PSTN Session Date' = $_.VoIPSessionDate.ToShortDateString()
					$row.'Number Of PSTN Sessions' = $_.NumberOfVoIPSessions
					$row.'Number Of Client Failure Responses (4xx)' = $_.NumberOf4xx
					$row.'Number Of Client Failure Responses (4xx) (%)' = [math]::round($_.NumberOf4xx_pct*100,2)
					$row.'Number Of Server Failure Responses (5xx)' = $_.NumberOf5xx
					$row.'Number Of Server Failure Responses (5xx) (%)' = [math]::round($_.NumberOf5xx_pct*100,2)
					$row.'Number Of Global Failure Responses (6xx)' = $_.NumberOf6xx
					$row.'Number Of Global Failure Responses (6xx) (%)' = [math]::round($_.NumberOf6xx_pct*100,2)
					#Add the row to the table
					$datatable.Rows.Add($row)
				}
			} 
			

		}

		$datatable | export-csv $OutputFileName -notypeinformation
	}
}

function WriteTitle ($TitleMessage) {
    $a.ForegroundColor = "green"
    WRITE-HOST $TitleMessage
    $a.ForegroundColor = $OriColor
    WRITE-HOST "----------------------------------------------------------------"
}

$a = (Get-Host).UI.RawUI
$ORIColor = $a.ForegroundColor

$date = (get-date -Format MM.dd.yyyy).toString()
$FolderName = $DataRoot + "\CQM_Data_" + $date

if (Test-Path $FolderName) {
    # CLEAN UP THE CONTENTS
    WRITE-warning "We have found some data in the folder $FolderName."

    $var = read-host -prompt "Type yes to continue or type no to exit the script."

    if ($var -eq "yes") {
        Remove-Item "$FolderName\*" -recurse
    }
    else {
        write-warning "Preserving data in the folder $FolderName and exiting the script"
        exit
    }
}
else {
    # CREATE THE FOLDER
    $createfolder = New-Item $FolderName -type directory
}

# Save parameters used
$alltext= "RunDate: "+$date+"`r`nStartTime: "+$StartTime+"`r`nEndTime: "+$EndTime+"`r`nQoECdrInstance: "+$QoECdrInstance+"`r`nDataRoot: "+$DataRoot+"`r`nQoECdrVersion: "+$QoECdrVersion+"`r`nPoorStreamCondition: "+$PoorStreamCondition+"`r`nExcludeST: "+$ExcludeST
write-output $alltext > $FolderName\parameters.txt

# Test to see if the poor stream condition has been specified
if ($PoorStreamCondition -eq "DefClassifiedPoorCall") {

    # We go with default settings ClassifiedPoorCall and S2S
    $PoorStreamCondition = "ClassifiedPoorCall"

    # Get the default PoorStreamCondition
    $PSCFileName = "$pwd\Queries\PoorStreamCondition_" + $PoorStreamCondition + ".txt" 

    # Test if file exists, if not exit
    if (!(Test-Path $PSCFileName)) {
        write-warning "Not able to find PoorStreamCondition file"
        write-host $PSCFileName
        exit
    }
    # Read the condition
    $PSCondition = [System.IO.File]::ReadAllText($PSCFileName)

    # Get the S2S PoorStreamCondition
    $S2SPSCFileName = "$pwd\Queries\PoorStreamCondition_S2S.txt" 

    # Test if file exists, if not exit
    if (!(Test-Path $S2SPSCFileName)) {
        write-warning "Not able to find PoorStreamCondition file"
        write-host $PSCFileName
        exit
    }
    # Read the condition
    $S2SPSCondition = [System.IO.File]::ReadAllText($S2SPSCFileName)
}
else {
    # Use specified condition for all queries
    # Get the default PoorStreamCondition
    $PSCFileName = "$pwd\Queries\PoorStreamCondition_" + $PoorStreamCondition + ".txt" 

    # Test if file exists, if not exit
    if (!(Test-Path $PSCFileName)) {
        write-warning "Not able to find PoorStreamCondition file"
        write-host $PSCFileName
        exit
    }
    # Read the condition
    $PSCondition = [System.IO.File]::ReadAllText($PSCFileName)
    $S2SPSCondition = [System.IO.File]::ReadAllText($PSCFileName)

}
# Save the condition
$alltext= "Type,Condition"
write-output $alltext > $FolderName\"PoorStreamCondition v15.csv"
$alltext= "PoorStreamCondition,"+$PSCondition
write-output $alltext >> $FolderName\"PoorStreamCondition v15.csv"
$alltext= "S2SPoorStreamCondition,"+$S2SPSCondition
write-output $alltext >> $FolderName\"PoorStreamCondition v15.csv"

# Gather the data
WriteTitle "Gathering the CQM results"

	ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_0_Device v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_0_Device v15.csv" "Device" $PSCondition
    ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_1_System v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_1_System v15.csv" "System" $PSCondition
    
    if ($QoECdrVersion -eq "Lync2010") {
	    ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_2_Relay_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_2_Relay v15.csv" "Relay" $PSCondition
        ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_3_Transport_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_3_Transport v15.csv" "Transport" $PSCondition
    } else {
        ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_2_Relay v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_2_Relay v15.csv" "Relay" $PSCondition
        ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_3_Transport v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_3_Transport v15.csv" "Transport" $PSCondition
    }
	
    ExportDataFromSQLInputFile "$pwd\Queries\Endpoint_2_VPN v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Endpoint_2_VPN v15.csv" "VPN" $PSCondition
    
    if ($QoECdrVersion -eq "Lync2010") {
    	ExportDataFromSQLInputFile "$pwd\Queries\LastMile_0_Wired_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\LastMile_0_Wired v15.csv" "LastMile" $PSCondition
        ExportDataFromSQLInputFile "$pwd\Queries\LastMile_1_Wireless_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\LastMile_1_Wireless v15.csv" "LastMile" $PSCondition
	} else {
        ExportDataFromSQLInputFile "$pwd\Queries\LastMile_0_Wired v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\LastMile_0_Wired v15.csv" "LastMile" $PSCondition
        ExportDataFromSQLInputFile "$pwd\Queries\LastMile_1_Wireless v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\LastMile_1_Wireless v15.csv" "LastMile" $PSCondition
    }

	ExportDataFromSQLInputFile "$pwd\Queries\Plant_1_AVMCU_Mediation v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Plant_1_AVMCU_Mediation v15.csv" "Plant1" $S2SPSCondition
	ExportDataFromSQLInputFile "$pwd\Queries\Plant_2_Mediation_Gateway v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Plant_2_Mediation_Gateway v15.csv" "Plant2" $S2SPSCondition

	ExportDataFromSQLInputFile "$pwd\Queries\Trend_1_AVMCU_Mediation v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_1_AVMCU_Mediation v15.csv" "Trend" $S2SPSCondition
	ExportDataFromSQLInputFile "$pwd\Queries\Trend_2_Mediation_Gateway v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_2_Mediation_Gateway v15.csv" "Trend" $S2SPSCondition

    if ($QoECdrVersion -eq "Lync2010") {
    	ExportDataFromSQLInputFile "$pwd\Queries\Trend_3_Wired_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_3_Wired v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_4_Wired_P2P_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_4_Wired_P2P v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_5_Other_Wired_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_5_Other_Wired v15.csv" "Trend" $PSCondition $ExcludeST
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_6_Other_Wireless_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_6_Other_Wireless v15.csv" "Trend" $PSCondition
    
	} else {
    	ExportDataFromSQLInputFile "$pwd\Queries\Trend_3_Wired v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_3_Wired v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_4_Wired_P2P v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_4_Wired_P2P v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_5_Other_Wired v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_5_Other_Wired v15.csv" "Trend" $PSCondition $ExcludeST
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_6_Other_Wireless v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_6_Other_Wireless v15.csv" "Trend" $PSCondition
    }

    ExportDataFromSQLInputFile "$pwd\Queries\Trend_7_VPN v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_7_VPN v15.csv" "Trend" $PSCondition
	ExportDataFromSQLInputFile "$pwd\Queries\Trend_8_External v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_8_External v15.csv" "Trend" $PSCondition
    
    if ($QoECdrVersion -eq "Lync2010") {
        ExportDataFromSQLInputFile "$pwd\Queries\Trend_9_Wireless_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_9_Wireless v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_10_Wireless_P2P_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_10_Wireless_P2P v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_11_Total_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_11_Total v15.csv" "Trend" $PSCondition
	
	} else {
        ExportDataFromSQLInputFile "$pwd\Queries\Trend_9_Wireless v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_9_Wireless v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_10_Wireless_P2P v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_10_Wireless_P2P v15.csv" "Trend" $PSCondition
	    ExportDataFromSQLInputFile "$pwd\Queries\Trend_11_Total v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Trend_11_Total v15.csv" "Trend" $PSCondition
    }
	ExportDataFromSQLInputFile "$pwd\Queries\Util_1_Users_Devices_Streams v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Util_1_Users_Devices_Streams v15.csv" "Util1" $PSCondition

    if ($QoECdrVersion -eq "Lync2010") {
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend v15.csv" "ConfTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend_fail-to-establish_breakdown_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_dialtone v15.csv" "ConfFailToEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend_ fail-mid-call_breakdown_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_calldrop v15.csv" "ConfFailMidCallEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_PSTN_Failures_Trend_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_PSTNFailure v15.csv" "ConfPSTNFailureTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend v15.csv" "P2PTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend_fail-to-establish_breakdown_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend_dialtone v15.csv" "P2PFailToEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend_fail-mid-call_breakdown_2010 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend_calldrop v15.csv" "P2PFailMidCallEstablishTrend"
    } else {
        ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend v15.csv" "ConfTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend_fail-to-establish_breakdown v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_dialtone v15.csv" "ConfFailToEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_Trend_ fail-mid-call_breakdown v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_calldrop v15.csv" "ConfFailMidCallEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_Conference_PSTN_Failures_Trend v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_ConfTrend_PSTNFailure v15.csv" "ConfPSTNFailureTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend v15.csv" "P2PTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend_fail-to-establish_breakdown v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend_dialtone v15.csv" "P2PFailToEstablishTrend"
	    ExportDataFromSQLInputFile "$pwd\Queries\Reliability_P2P_Trend_fail-mid-call_breakdown v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\Rel_P2PTrend_calldrop v15.csv" "P2PFailMidCallEstablishTrend"
    }
    
    if ($QoECdrVersion -eq "SfB2015") {
		ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_3_Wired_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_3_Wired v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_4_Wired_P2P_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_4_Wired_P2P v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_5_Other_Wired_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_5_Other_Wired v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_6_Other_Wireless_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_6_Other_Wireless v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_7_VPN_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_7_VPN v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_8_External_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_8_External v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_9_Wireless_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_9_Wireless v15.csv" "RMC"
	    ExportDataFromSQLInputFile "$pwd\Queries\RMC_Trend_10_Wireless_P2P_2015 v15.txt" "'$StartTime'" "'$EndTime'" $QoECdrInstance "$FolderName\RMC_Trend_10_Wireless_P2P v15.csv" "RMC"
    }

















# SIG # Begin signature block
# MIIanwYJKoZIhvcNAQcCoIIakDCCGowCAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUbnfOwWCrklbVHxEWLDaLqeFu
# Pw+gghWCMIIEwzCCA6ugAwIBAgITMwAAAHGzLoprgqofTgAAAAAAcTANBgkqhkiG
# 9w0BAQUFADB3MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4G
# A1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSEw
# HwYDVQQDExhNaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EwHhcNMTUwMzIwMTczMjAz
# WhcNMTYwNjIwMTczMjAzWjCBszELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjENMAsGA1UECxMETU9QUjEnMCUGA1UECxMebkNpcGhlciBEU0UgRVNO
# OkI4RUMtMzBBNC03MTQ0MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBT
# ZXJ2aWNlMIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEA6pG9soj9FG8h
# NigDZjM6Zgj7W0ukq6AoNEpDMgjAhuXJPdUlvHs+YofWfe8PdFOj8ZFjiHR/6CTN
# A1DF8coAFnulObAGHDxEfvnrxLKBvBcjuv1lOBmFf8qgKf32OsALL2j04DROfW8X
# wG6Zqvp/YSXRJnDSdH3fYXNczlQqOVEDMwn4UK14x4kIttSFKj/X2B9R6u/8aF61
# wecHaDKNL3JR/gMxR1HF0utyB68glfjaavh3Z+RgmnBMq0XLfgiv5YHUV886zBN1
# nSbNoKJpULw6iJTfsFQ43ok5zYYypZAPfr/tzJQlpkGGYSbH3Td+XA3oF8o3f+gk
# tk60+Bsj6wIDAQABo4IBCTCCAQUwHQYDVR0OBBYEFPj9I4cFlIBWzTOlQcJszAg2
# yLKiMB8GA1UdIwQYMBaAFCM0+NlSRnAK7UD7dvuzK7DDNbMPMFQGA1UdHwRNMEsw
# SaBHoEWGQ2h0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3Rz
# L01pY3Jvc29mdFRpbWVTdGFtcFBDQS5jcmwwWAYIKwYBBQUHAQEETDBKMEgGCCsG
# AQUFBzAChjxodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY3Jv
# c29mdFRpbWVTdGFtcFBDQS5jcnQwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDQYJKoZI
# hvcNAQEFBQADggEBAC0EtMopC1n8Luqgr0xOaAT4ku0pwmbMa3DJh+i+h/xd9N1P
# pRpveJetawU4UUFynTnkGhvDbXH8cLbTzLaQWAQoP9Ye74OzFBgMlQv3pRETmMaF
# Vl7uM7QMN7WA6vUSaNkue4YIcjsUe9TZ0BZPwC8LHy3K5RvQrumEsI8LXXO4FoFA
# I1gs6mGq/r1/041acPx5zWaWZWO1BRJ24io7K+2CrJrsJ0Gnlw4jFp9ByE5tUxFA
# BMxgmdqY7Cuul/vgffW6iwD0JRd/Ynq7UVfB8PDNnBthc62VjCt2IqircDi0ASh9
# ZkJT3p/0B3xaMA6CA1n2hIa5FSVisAvSz/HblkUwggTsMIID1KADAgECAhMzAAAA
# ymzVMhI1xOFVAAEAAADKMA0GCSqGSIb3DQEBBQUAMHkxCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xIzAhBgNVBAMTGk1pY3Jvc29mdCBDb2RlIFNp
# Z25pbmcgUENBMB4XDTE0MDQyMjE3MzkwMFoXDTE1MDcyMjE3MzkwMFowgYMxCzAJ
# BgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25k
# MR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xDTALBgNVBAsTBE1PUFIx
# HjAcBgNVBAMTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjCCASIwDQYJKoZIhvcNAQEB
# BQADggEPADCCAQoCggEBAJZxXe0GRvqEy51bt0bHsOG0ETkDrbEVc2Cc66e2bho8
# P/9l4zTxpqUhXlaZbFjkkqEKXMLT3FIvDGWaIGFAUzGcbI8hfbr5/hNQUmCVOlu5
# WKV0YUGplOCtJk5MoZdwSSdefGfKTx5xhEa8HUu24g/FxifJB+Z6CqUXABlMcEU4
# LYG0UKrFZ9H6ebzFzKFym/QlNJj4VN8SOTgSL6RrpZp+x2LR3M/tPTT4ud81MLrs
# eTKp4amsVU1Mf0xWwxMLdvEH+cxHrPuI1VKlHij6PS3Pz4SYhnFlEc+FyQlEhuFv
# 57H8rEBEpamLIz+CSZ3VlllQE1kYc/9DDK0r1H8wQGcCAwEAAaOCAWAwggFcMBMG
# A1UdJQQMMAoGCCsGAQUFBwMDMB0GA1UdDgQWBBQfXuJdUI1Whr5KPM8E6KeHtcu/
# gzBRBgNVHREESjBIpEYwRDENMAsGA1UECxMETU9QUjEzMDEGA1UEBRMqMzE1OTUr
# YjQyMThmMTMtNmZjYS00OTBmLTljNDctM2ZjNTU3ZGZjNDQwMB8GA1UdIwQYMBaA
# FMsR6MrStBZYAck3LjMWFrlMmgofMFYGA1UdHwRPME0wS6BJoEeGRWh0dHA6Ly9j
# cmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1Y3RzL01pY0NvZFNpZ1BDQV8w
# OC0zMS0yMDEwLmNybDBaBggrBgEFBQcBAQROMEwwSgYIKwYBBQUHMAKGPmh0dHA6
# Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljQ29kU2lnUENBXzA4LTMx
# LTIwMTAuY3J0MA0GCSqGSIb3DQEBBQUAA4IBAQB3XOvXkT3NvXuD2YWpsEOdc3wX
# yQ/tNtvHtSwbXvtUBTqDcUCBCaK3cSZe1n22bDvJql9dAxgqHSd+B+nFZR+1zw23
# VMcoOFqI53vBGbZWMrrizMuT269uD11E9dSw7xvVTsGvDu8gm/Lh/idd6MX/YfYZ
# 0igKIp3fzXCCnhhy2CPMeixD7v/qwODmHaqelzMAUm8HuNOIbN6kBjWnwlOGZRF3
# CY81WbnYhqgA/vgxfSz0jAWdwMHVd3Js6U1ZJoPxwrKIV5M1AHxQK7xZ/P4cKTiC
# 095Sl0UpGE6WW526Xxuj8SdQ6geV6G00DThX3DcoNZU6OJzU7WqFXQ4iEV57MIIF
# vDCCA6SgAwIBAgIKYTMmGgAAAAAAMTANBgkqhkiG9w0BAQUFADBfMRMwEQYKCZIm
# iZPyLGQBGRYDY29tMRkwFwYKCZImiZPyLGQBGRYJbWljcm9zb2Z0MS0wKwYDVQQD
# EyRNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0ZSBBdXRob3JpdHkwHhcNMTAwODMx
# MjIxOTMyWhcNMjAwODMxMjIyOTMyWjB5MQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMSMwIQYDVQQDExpNaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBD
# QTCCASIwDQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBALJyWVwZMGS/HZpgICBC
# mXZTbD4b1m/My/Hqa/6XFhDg3zp0gxq3L6Ay7P/ewkJOI9VyANs1VwqJyq4gSfTw
# aKxNS42lvXlLcZtHB9r9Jd+ddYjPqnNEf9eB2/O98jakyVxF3K+tPeAoaJcap6Vy
# c1bxF5Tk/TWUcqDWdl8ed0WDhTgW0HNbBbpnUo2lsmkv2hkL/pJ0KeJ2L1TdFDBZ
# +NKNYv3LyV9GMVC5JxPkQDDPcikQKCLHN049oDI9kM2hOAaFXE5WgigqBTK3S9dP
# Y+fSLWLxRT3nrAgA9kahntFbjCZT6HqqSvJGzzc8OJ60d1ylF56NyxGPVjzBrAlf
# A9MCAwEAAaOCAV4wggFaMA8GA1UdEwEB/wQFMAMBAf8wHQYDVR0OBBYEFMsR6MrS
# tBZYAck3LjMWFrlMmgofMAsGA1UdDwQEAwIBhjASBgkrBgEEAYI3FQEEBQIDAQAB
# MCMGCSsGAQQBgjcVAgQWBBT90TFO0yaKleGYYDuoMW+mPLzYLTAZBgkrBgEEAYI3
# FAIEDB4KAFMAdQBiAEMAQTAfBgNVHSMEGDAWgBQOrIJgQFYnl+UlE/wq4QpTlVnk
# pDBQBgNVHR8ESTBHMEWgQ6BBhj9odHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtp
# L2NybC9wcm9kdWN0cy9taWNyb3NvZnRyb290Y2VydC5jcmwwVAYIKwYBBQUHAQEE
# SDBGMEQGCCsGAQUFBzAChjhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2Nl
# cnRzL01pY3Jvc29mdFJvb3RDZXJ0LmNydDANBgkqhkiG9w0BAQUFAAOCAgEAWTk+
# fyZGr+tvQLEytWrrDi9uqEn361917Uw7LddDrQv+y+ktMaMjzHxQmIAhXaw9L0y6
# oqhWnONwu7i0+Hm1SXL3PupBf8rhDBdpy6WcIC36C1DEVs0t40rSvHDnqA2iA6VW
# 4LiKS1fylUKc8fPv7uOGHzQ8uFaa8FMjhSqkghyT4pQHHfLiTviMocroE6WRTsgb
# 0o9ylSpxbZsa+BzwU9ZnzCL/XB3Nooy9J7J5Y1ZEolHN+emjWFbdmwJFRC9f9Nqu
# 1IIybvyklRPk62nnqaIsvsgrEA5ljpnb9aL6EiYJZTiU8XofSrvR4Vbo0HiWGFzJ
# NRZf3ZMdSY4tvq00RBzuEBUaAF3dNVshzpjHCe6FDoxPbQ4TTj18KUicctHzbMrB
# 7HCjV5JXfZSNoBtIA1r3z6NnCnSlNu0tLxfI5nI3EvRvsTxngvlSso0zFmUeDord
# EN5k9G/ORtTTF+l5xAS00/ss3x+KnqwK+xMnQK3k+eGpf0a7B2BHZWBATrBC7E7t
# s3Z52Ao0CW0cgDEf4g5U3eWh++VHEK1kmP9QFi58vwUheuKVQSdpw5OPlcmN2Jsh
# rg1cnPCiroZogwxqLbt2awAdlq3yFnv2FoMkuYjPaqhHMS+a3ONxPdcAfmJH0c6I
# ybgY+g5yjcGjPa8CQGr/aZuW4hCoELQ3UAjWwz0wggYHMIID76ADAgECAgphFmg0
# AAAAAAAcMA0GCSqGSIb3DQEBBQUAMF8xEzARBgoJkiaJk/IsZAEZFgNjb20xGTAX
# BgoJkiaJk/IsZAEZFgltaWNyb3NvZnQxLTArBgNVBAMTJE1pY3Jvc29mdCBSb290
# IENlcnRpZmljYXRlIEF1dGhvcml0eTAeFw0wNzA0MDMxMjUzMDlaFw0yMTA0MDMx
# MzAzMDlaMHcxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
# VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xITAf
# BgNVBAMTGE1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQTCCASIwDQYJKoZIhvcNAQEB
# BQADggEPADCCAQoCggEBAJ+hbLHf20iSKnxrLhnhveLjxZlRI1Ctzt0YTiQP7tGn
# 0UytdDAgEesH1VSVFUmUG0KSrphcMCbaAGvoe73siQcP9w4EmPCJzB/LMySHnfL0
# Zxws/HvniB3q506jocEjU8qN+kXPCdBer9CwQgSi+aZsk2fXKNxGU7CG0OUoRi4n
# rIZPVVIM5AMs+2qQkDBuh/NZMJ36ftaXs+ghl3740hPzCLdTbVK0RZCfSABKR2YR
# JylmqJfk0waBSqL5hKcRRxQJgp+E7VV4/gGaHVAIhQAQMEbtt94jRrvELVSfrx54
# QTF3zJvfO4OToWECtR0Nsfz3m7IBziJLVP/5BcPCIAsCAwEAAaOCAaswggGnMA8G
# A1UdEwEB/wQFMAMBAf8wHQYDVR0OBBYEFCM0+NlSRnAK7UD7dvuzK7DDNbMPMAsG
# A1UdDwQEAwIBhjAQBgkrBgEEAYI3FQEEAwIBADCBmAYDVR0jBIGQMIGNgBQOrIJg
# QFYnl+UlE/wq4QpTlVnkpKFjpGEwXzETMBEGCgmSJomT8ixkARkWA2NvbTEZMBcG
# CgmSJomT8ixkARkWCW1pY3Jvc29mdDEtMCsGA1UEAxMkTWljcm9zb2Z0IFJvb3Qg
# Q2VydGlmaWNhdGUgQXV0aG9yaXR5ghB5rRahSqClrUxzWPQHEy5lMFAGA1UdHwRJ
# MEcwRaBDoEGGP2h0dHA6Ly9jcmwubWljcm9zb2Z0LmNvbS9wa2kvY3JsL3Byb2R1
# Y3RzL21pY3Jvc29mdHJvb3RjZXJ0LmNybDBUBggrBgEFBQcBAQRIMEYwRAYIKwYB
# BQUHMAKGOGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2kvY2VydHMvTWljcm9z
# b2Z0Um9vdENlcnQuY3J0MBMGA1UdJQQMMAoGCCsGAQUFBwMIMA0GCSqGSIb3DQEB
# BQUAA4ICAQAQl4rDXANENt3ptK132855UU0BsS50cVttDBOrzr57j7gu1BKijG1i
# uFcCy04gE1CZ3XpA4le7r1iaHOEdAYasu3jyi9DsOwHu4r6PCgXIjUji8FMV3U+r
# kuTnjWrVgMHmlPIGL4UD6ZEqJCJw+/b85HiZLg33B+JwvBhOnY5rCnKVuKE5nGct
# xVEO6mJcPxaYiyA/4gcaMvnMMUp2MT0rcgvI6nA9/4UKE9/CCmGO8Ne4F+tOi3/F
# NSteo7/rvH0LQnvUU3Ih7jDKu3hlXFsBFwoUDtLaFJj1PLlmWLMtL+f5hYbMUVbo
# nXCUbKw5TNT2eb+qGHpiKe+imyk0BncaYsk9Hm0fgvALxyy7z0Oz5fnsfbXjpKh0
# NbhOxXEjEiZ2CzxSjHFaRkMUvLOzsE1nyJ9C/4B5IYCeFTBm6EISXhrIniIh0EPp
# K+m79EjMLNTYMoBMJipIJF9a6lbvpt6Znco6b72BJ3QGEe52Ib+bgsEnVLaxaj2J
# oXZhtG6hE6a/qkfwEm/9ijJssv7fUciMI8lmvZ0dhxJkAj0tr1mPuOQh5bWwymO0
# eFQF1EEuUKyUsKV4q7OglnUa2ZKHE3UiLzKoCG6gW4wlv6DvhMoh1useT8ma7kng
# 9wFlb4kLfchpyOZu6qeXzjEp/w7FW1zYTRuh2Povnj8uVRZryROj/TGCBIcwggSD
# AgEBMIGQMHkxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYD
# VQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xIzAh
# BgNVBAMTGk1pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBAhMzAAAAymzVMhI1xOFV
# AAEAAADKMAkGBSsOAwIaBQCggaAwGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQw
# HAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwIwYJKoZIhvcNAQkEMRYEFARH
# GnPQh4gn+paoZGwx2+90sUoGMEAGCisGAQQBgjcCAQwxMjAwoBCADgBDAFEATQAu
# AHAAcwAxoRyAGmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS8gMA0GCSqGSIb3DQEB
# AQUABIIBAALCV7R+L0EHPT+39/LnmpYepDYyT3vujeuSO/4/NSj3iRJ+xPo2GJ3T
# cB09nMsKEw/uWcQjXuUgdvSPDUydCKjWcFsU+2eacFQdfIrQfEdSW0ZKRD1cMx8S
# iJTvnhauYdyH53b3avXhBw6XQYX325/mqfwFUtlxe5vdVWOSjzZ/iYgLl3NAiCDf
# uBKXdz2ZEQr3VM3/4UY3F4mXVQ7dv6hMBWJUwEcNZoG/KFmjPuvAUnzg2biAtejw
# b5W0VnG70m/IRsbzU5W93z3suckhAsytGKN6EbiNAj4SNLUzsYSXmnuJyOGncfOg
# ro/JFhyH7dZ8IYPTjV/GmhWE7jpoZQehggIoMIICJAYJKoZIhvcNAQkGMYICFTCC
# AhECAQEwgY4wdzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEh
# MB8GA1UEAxMYTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBAhMzAAAAcbMuimuCqh9O
# AAAAAABxMAkGBSsOAwIaBQCgXTAYBgkqhkiG9w0BCQMxCwYJKoZIhvcNAQcBMBwG
# CSqGSIb3DQEJBTEPFw0xNTA1MjcyMDEzMjVaMCMGCSqGSIb3DQEJBDEWBBQIZKoP
# 5DomQOEtovmAHkEN6LJdxzANBgkqhkiG9w0BAQUFAASCAQB/xfB/tsmwa0D8jqi5
# /8LMsXeiyFWgOLSlN5ErCqFQoaM2LGVlD9zZp1tbGv379k0FqrfDjLSBgzEv1Xp8
# FXv5IBeU3pROH/7yVBiPUApWpZIr6XDWWQ4nX6XqDTG45SiHOVclVyKrP6E6QqJQ
# PbIAsEYM3VQXP4fPR4CimLkjU7ecU9qrbKsA8wDokwkiCNFzE1ImkiyIf1yd3R5G
# yi5SwBt6TpXJd7m74DCf4getQ1Wvn6AWwfdAC0Z4C5od1AabSVo7T74sPejdwhZa
# sdS3sLxjB6RRIJxVtb1D2LxsFjPhXZ1aiNoXKKOYIgYzUb8Zo/uWMNH1K+MrnQAB
# 5A0m
# SIG # End signature block
